# Error Analysis SDK for Python

### This package has been tested with Python 3.5, 3.6 and 3.7

The error analysis sdk enables users to get a deeper understanding of machine learning model errors. When evaluating a machine learning model, aggregate accuracy is not sufficient and single-score evaluation may hide important conditions of inaccuracies. Use Error Analysis to identify cohorts with higher error rates and diagnose the root causes behind these errors.

Highlights of the package include:

- The error heatmap to investigate how one or two input features impact the error rate across cohorts
- The decision tree surrogate model trained on errors to discover cohorts with high error rates across multiple features. Investigate indicators such as error rate, error coverage, and data representation for each discovered cohort.

Please see the main documentation website:
https://erroranalysis.ai/

Auto-generated sphinx API documentation can be found here:
https://erroranalysis.ai/raiwidgets.html

The open source code can be found here:
https://github.com/microsoft/responsible-ai-widgets
